@@ -3,7 +3,7 @@ Routines related to PollyXT files
 """
 
 from pathlib import Path
-from typing import Tuple, Union
+from typing import Iterable, Tuple, Union
 from datetime import datetime, timedelta
 
 import numpy as np
@@ -34,7 +34,9 @@ def polly_date_to_datetime(timestamp: Tuple[int, int]) -> datetime:
     return date + timedelta(seconds=int(seconds))
 
 
-def get_measurement_period(input: Union[Path, Dataset, np.ndarray]) -> Tuple[datetime, datetime]:
+def get_measurement_period(
+    input: Union[Path, Dataset, np.ndarray]
+) -> Tuple[datetime, datetime]:
     """
     Return the measurement time (i.e. start and end times) from a PollyXT file.
 
@@ -129,7 +131,9 @@ class PollyXTRepository:
         elif self.path.is_file():
             self.files = [self.path]
         else:
-            raise ValueError(f"Path {self.path} doesn't seem to be either a file or a directory")
+            raise ValueError(
+                f"Path {self.path} doesn't seem to be either a file or a directory"
+            )
 
         if len(self.files) == 0:
             raise NoFilesFound(self.path)
@@ -139,17 +143,28 @@ class PollyXTRepository:
         for path in self.files:
             with Dataset(path, "r") as nc:
                 measurement_time = nc["measurement_time"][:]
-                for i, timestamp in enumerate(measurement_time):
+                depol_cal_angle = nc["depol_cal_angle"][:]
+                for i, (timestamp, dcv) in enumerate(
+                    zip(measurement_time, depol_cal_angle)
+                ):
                     # Parse date
                     try:
                         timestamp = polly_date_to_datetime(timestamp)
                     except ValueError:
                         raise BadMeasurementTime(path, timestamp)
 
-                    rows.append({"timestamp": timestamp, "index": i, "path": path})
+                    rows.append(
+                        {
+                            "timestamp": timestamp,
+                            "index": i,
+                            "path": path,
+                            "depol_cal_angle": dcv,
+                        }
+                    )
 
         self.index = pd.DataFrame(rows)
         self.index = self.index.sort_values("timestamp", ascending=True)
+        self.index["calibration"] = self.index["depol_cal_angle"] != 0
 
     def get_time_period(self) -> Tuple[datetime, datetime]:
         """
@@ -164,6 +179,23 @@ class PollyXTRepository:
 
         return start, end
 
+    def get_calibration_periods(self) -> Iterable[Tuple[datetime, datetime]]:
+        """
+        Returns a list of periods that refer to calibration times.
+
+        This function checks when the `depol_cal_angle` variable is not 0 and returns
+        the time periods that this occures.
+
+        Returns:
+            List[Tuple[datetime, datetime]]: A list containing periods (ie. tuples of start-time and end-time)
+        """
+
+        groups = (self.index.calibration != self.index.calibration.shift()).cumsum()
+
+        for i, g in self.index.groupby(groups):
+            if g.depol_cal_angle.sum() != 0:
+                yield g.iloc[0]["timestamp"], g.iloc[-1]["timestamp"]
+
     def get_pollyxt_file(self, time_start: datetime, time_end: datetime):
         """
         Create a PollyXTFile for the given time range.
@@ -177,7 +209,9 @@ class PollyXTRepository:
         """
 
         # Filter index for given time range
-        mask = (self.index["timestamp"] >= time_start) & (self.index["timestamp"] <= time_end)
+        mask = (self.index["timestamp"] >= time_start) & (
+            self.index["timestamp"] <= time_end
+        )
         targets = self.index[mask]
         if targets.shape[0] == 0:
             raise NoMeasurementsInTimePeriod()
@@ -195,21 +229,44 @@ class PollyXTRepository:
         # Concatenate data into one file
         pollyxt_file = polly_files[0]
         pollyxt_file.raw_signal = np.concatenate([x.raw_signal for x in polly_files])
-        pollyxt_file.raw_signal_swap = np.concatenate([x.raw_signal_swap for x in polly_files])
-        pollyxt_file.measurement_time = np.concatenate([x.measurement_time for x in polly_files])
-        pollyxt_file.measurement_shots = np.concatenate([x.measurement_shots for x in polly_files])
+        pollyxt_file.raw_signal_swap = np.concatenate(
+            [x.raw_signal_swap for x in polly_files]
+        )
+        pollyxt_file.measurement_time = np.concatenate(
+            [x.measurement_time for x in polly_files]
+        )
+        pollyxt_file.measurement_shots = np.concatenate(
+            [x.measurement_shots for x in polly_files]
+        )
         try:
-            pollyxt_file.zenith_angle = np.concatenate([x.zenith_angle for x in polly_files])
+            pollyxt_file.zenith_angle = np.concatenate(
+                [x.zenith_angle for x in polly_files]
+            )
         except ValueError:
             # Sometimes these arrays are empty, this is not a problem
             pass
-        pollyxt_file.depol_cal_angle = np.concatenate([x.depol_cal_angle for x in polly_files])
+        pollyxt_file.depol_cal_angle = np.concatenate(
+            [x.depol_cal_angle for x in polly_files]
+        )
 
         pollyxt_file.end_date = polly_files[-1].end_date
 
         return pollyxt_file
 
 
+def make_nan_during_calibration(depol_cal_angle: np.ndarray, raw_signal: np.ndarray):
+    """
+    Given the depol_cal_angle and raw_signal arrays, set raw_signal to NaN during
+    calibrations. The raw_signal array is mutated.
+
+    Args:
+        depol_cal_angle: The depol_cal_angle array from a `PollyXTFile`
+        raw_signal: The raw_signal array from a `PollyXTFile`
+    """
+    depol_cal_time = depol_cal_angle != 0.0
+    raw_signal[depol_cal_time, :, :] = np.nan
+
+
 class PollyXTFile:
     """
     Reads the variables of interest from a PollyXT netCDF file.
@@ -229,7 +286,9 @@ class PollyXTFile:
     location_coordinates: np.ndarray
     depol_cal_angle: np.ndarray
 
-    def __init__(self, input_path: Path, start: int = None, end: int = None, nan_calibration=True):
+    def __init__(
+        self, input_path: Path, start: int = None, end: int = None, nan_calibration=True
+    ):
         """
         Read a PollyXT netcdf file
 
@@ -253,21 +312,23 @@ class PollyXTFile:
         self.measurement_time = self.measurement_time[start : end + 1]
 
         # Read the rest of the variables
+        # raw_signal is converted to float64 for two reasons:
+        # 1. SCC requires it as float64
+        # 2. So we can set it to NaN during calibration
         self.raw_signal = nc["raw_signal"][start : end + 1, :, :]
+        self.raw_signal = np.array(self.raw_signal, dtype=np.float64)
         self.raw_signal_swap = np.swapaxes(self.raw_signal, 1, 2)
 
         self.measurement_shots = nc["measurement_shots"][start : end + 1, :]
         self.zenith_angle = nc["zenithangle"][:]
         self.location_coordinates = nc["location_coordinates"][:]
-        self.depol_cal_angle = nc["depol_cal_angle"][:]
+        self.depol_cal_angle = nc["depol_cal_angle"][start : end + 1]
 
         nc.close()
 
         # Optionally set calibration times to nan
         if nan_calibration:
-            depol_cal_time = np.where(self.depol_cal_angle != 0.0)[0]
-            if depol_cal_time.size != 0:
-                self.raw_signal[depol_cal_time[0] : depol_cal_time[-1], :, :] == np.nan
+            make_nan_during_calibration(self.depol_cal_angle, self.raw_signal)
 
         # Store some variables for easy access
         self.start_index = start
