@@ -13,7 +13,10 @@ import numpy as np
 from pollyxt_pipelines.polly_to_scc import pollyxt
 from pollyxt_pipelines.locations import Location
 from pollyxt_pipelines import utils
-from pollyxt_pipelines.polly_to_scc.exceptions import NoMeasurementsInTimePeriod, TimeOutsideFile
+from pollyxt_pipelines.polly_to_scc.exceptions import (
+    NoMeasurementsInTimePeriod,
+    TimeOutsideFile,
+)
 
 
 class Wavelength(Enum):
@@ -48,27 +51,6 @@ class Atmosphere(IntEnum):
         raise ValueError(f"Unknown atmosphere {x}")
 
 
-"""When calibration takes place each day, in HH:MM-HH:MM format"""
-CALIBRATION_PERIODS = ["02:31-02:41", "17:31-17:41", "21:31-21:41"]
-
-
-def calibration_to_datetime(base: datetime, period: str) -> Tuple[datetime, datetime]:
-    """
-    Given a calibrarion period in HH:MM-HH:MM format (start-end), it converts it to a pair of `datetime`, the same day
-    as the given `base`.
-    """
-    base = base.replace(hour=0, minute=0, second=0)
-
-    start, end = period.split("-")
-    start = [int(x) for x in start.split(":")]
-    end = [int(x) for x in end.split(":")]
-
-    start = base + timedelta(hours=start[0], minutes=start[1])
-    end = base + timedelta(hours=end[0], minutes=end[1])
-
-    return start, end
-
-
 def create_scc_netcdf(
     pf: pollyxt.PollyXTFile,
     output_path: Path,
@@ -127,9 +109,9 @@ def create_scc_netcdf(
     if pf.start_date.replace(
         hour=4, minute=0
     ) < pf.start_date and pf.start_date < pf.start_date.replace(hour=16, minute=0):
-        nc.NOAReACT_Configuration_ID = location.daytime_configuration
+        nc.X_PollyXTPipelines_Configuration_ID = location.daytime_configuration
     else:
-        nc.NOAReACT_Configuration_ID = location.nighttime_configuration
+        nc.X_PollyXTPipelines_Configuration_ID = location.nighttime_configuration
 
     # Create Variables. (mandatory)
     raw_data_start_time = nc.createVariable(
@@ -141,8 +123,12 @@ def create_scc_netcdf(
     raw_lidar_data = nc.createVariable(
         "Raw_Lidar_Data", "f8", dimensions=("time", "channels", "points"), zlib=True
     )
-    channel_id = nc.createVariable("channel_ID", "i4", dimensions=("channels"), zlib=True)
-    id_timescale = nc.createVariable("id_timescale", "i4", dimensions=("channels"), zlib=True)
+    channel_id = nc.createVariable(
+        "channel_ID", "i4", dimensions=("channels"), zlib=True
+    )
+    id_timescale = nc.createVariable(
+        "id_timescale", "i4", dimensions=("channels"), zlib=True
+    )
     laser_pointing_angle = nc.createVariable(
         "Laser_Pointing_Angle", "f8", dimensions=("scan_angles"), zlib=True
     )
@@ -152,9 +138,15 @@ def create_scc_netcdf(
         dimensions=("time", "nb_of_time_scales"),
         zlib=True,
     )
-    laser_shots = nc.createVariable("Laser_Shots", "i4", dimensions=("time", "channels"), zlib=True)
-    background_low = nc.createVariable("Background_Low", "f8", dimensions=("channels"), zlib=True)
-    background_high = nc.createVariable("Background_High", "f8", dimensions=("channels"), zlib=True)
+    laser_shots = nc.createVariable(
+        "Laser_Shots", "i4", dimensions=("time", "channels"), zlib=True
+    )
+    background_low = nc.createVariable(
+        "Background_Low", "f8", dimensions=("channels"), zlib=True
+    )
+    background_high = nc.createVariable(
+        "Background_High", "f8", dimensions=("channels"), zlib=True
+    )
     molecular_calc = nc.createVariable("Molecular_Calc", "i4", dimensions=(), zlib=True)
     nc.createVariable("Pol_Calib_Range_Min", "f8", dimensions=("channels"), zlib=True)
     nc.createVariable("Pol_Calib_Range_Max", "f8", dimensions=("channels"), zlib=True)
@@ -256,8 +248,12 @@ def create_scc_calibration_netcdf(
     raw_lidar_data = nc.createVariable(
         "Raw_Lidar_Data", "f8", dimensions=("time", "channels", "points"), zlib=True
     )
-    channel_id = nc.createVariable("channel_ID", "i4", dimensions=("channels"), zlib=True)
-    id_timescale = nc.createVariable("id_timescale", "i4", dimensions=("channels"), zlib=True)
+    channel_id = nc.createVariable(
+        "channel_ID", "i4", dimensions=("channels"), zlib=True
+    )
+    id_timescale = nc.createVariable(
+        "id_timescale", "i4", dimensions=("channels"), zlib=True
+    )
     laser_pointing_angle = nc.createVariable(
         "Laser_Pointing_Angle", "f8", dimensions=("scan_angles"), zlib=True
     )
@@ -267,9 +263,15 @@ def create_scc_calibration_netcdf(
         dimensions=("time", "nb_of_time_scales"),
         zlib=True,
     )
-    laser_shots = nc.createVariable("Laser_Shots", "i4", dimensions=("time", "channels"), zlib=True)
-    background_low = nc.createVariable("Background_Low", "f8", dimensions=("channels"), zlib=True)
-    background_high = nc.createVariable("Background_High", "f8", dimensions=("channels"), zlib=True)
+    laser_shots = nc.createVariable(
+        "Laser_Shots", "i4", dimensions=("time", "channels"), zlib=True
+    )
+    background_low = nc.createVariable(
+        "Background_Low", "f8", dimensions=("channels"), zlib=True
+    )
+    background_high = nc.createVariable(
+        "Background_High", "f8", dimensions=("channels"), zlib=True
+    )
     molecular_calc = nc.createVariable("Molecular_Calc", "i4", dimensions=(), zlib=True)
     pol_calib_range_min_var = nc.createVariable(
         "Pol_Calib_Range_Min", "f8", dimensions=("channels"), zlib=True
@@ -309,11 +311,17 @@ def create_scc_calibration_netcdf(
         cross_channel = location.cross_channel_355_nm
         channel_id[:] = np.array(location.calibration_355nm_channel_ids)
         nc.Measurement_ID = measurement_id + "35"
+        nc.X_PollyXTPipelines_Configuration_ID = (
+            location.calibration_configuration_355nm
+        )
     elif wavelength == Wavelength.NM_532:
         total_channel = location.total_channel_532_nm
         cross_channel = location.cross_channel_532_nm
         channel_id[:] = np.array(location.calibration_532nm_channel_ids)
         nc.Measurement_ID = measurement_id + "53"
+        nc.X_PollyXTPipelines_Configuration_ID = (
+            location.calibration_configuration_532nm
+        )
     else:
         raise ValueError(f"Unknown wavelength {wavelength}")
 
@@ -413,7 +421,9 @@ def convert_pollyxt_file(
 
         # Open netCDF file and convert to SCC
         try:
-            pf = repo.get_pollyxt_file(interval_start, interval_end + timedelta(seconds=30))
+            pf = repo.get_pollyxt_file(
+                interval_start, interval_end + timedelta(seconds=30)
+            )
             id, path = create_scc_netcdf(pf, output_path, location, atmosphere)
 
             yield id, path, pf.start_date, pf.end_date
@@ -426,21 +436,18 @@ def convert_pollyxt_file(
         interval_start = interval_end
 
     # Generate calibration files
-    # - 02:31 to 02:41
-    # - 17:31 to 17:41
-    # - 21:31 to 21:41
     if calibration:
         # Check for any valid calibration intervals
-        for period in CALIBRATION_PERIODS:
-            start, end = calibration_to_datetime(measurement_start, period)
-
+        for start, end in repo.get_calibration_periods():
             if start > measurement_start and end < measurement_end:
-                try:
-                    pf = repo.get_pollyxt_file(start, end)
-                    id, path = create_scc_calibration_netcdf(
-                        pf, output_path, location, wavelength=Wavelength.NM_532
-                    )
+                pf = repo.get_pollyxt_file(start, end)
 
-                    yield id, path, start, end
-                except NoMeasurementsInTimePeriod:
-                    pass
+                id, path = create_scc_calibration_netcdf(
+                    pf, output_path, location, wavelength=Wavelength.NM_532
+                )
+                yield id, path, start, end
+
+                id, path = create_scc_calibration_netcdf(
+                    pf, output_path, location, wavelength=Wavelength.NM_355
+                )
+                yield id, path, start, end
